package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.CaEmissionForecast;

/**
 * 碳排放预测Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
public interface CaEmissionForecastMapper
{
    /**
     * 查询碳排放预测
     * 
     * @param id 碳排放预测主键
     * @return 碳排放预测
     */
     CaEmissionForecast selectCaEmissionForecastById(Long id);

    /**
     * 查询碳排放预测列表
     * 
     * @param admEmsCaEmissionForecast 碳排放预测
     * @return 碳排放预测集合
     */
     List<CaEmissionForecast> selectCaEmissionForecastList(CaEmissionForecast admEmsCaEmissionForecast);

    /**
     * 新增碳排放预测
     * 
     * @param admEmsCaEmissionForecast 碳排放预测
     * @return 结果
     */
     int insertCaEmissionForecast(CaEmissionForecast admEmsCaEmissionForecast);

    /**
     * 修改碳排放预测
     * 
     * @param admEmsCaEmissionForecast 碳排放预测
     * @return 结果
     */
     int updateCaEmissionForecast(CaEmissionForecast admEmsCaEmissionForecast);

    /**
     * 删除碳排放预测
     * 
     * @param id 碳排放预测主键
     * @return 结果
     */
     int deleteCaEmissionForecastById(Long id);

    /**
     * 批量删除碳排放预测
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteCaEmissionForecastByIds(Long[] ids);
}
